=== modified file 'NEWS.developers'
--- NEWS.developers	2005-09-30 00:58:02 +0000
+++ NEWS.developers	2005-10-06 06:31:16 +0000
@@ -11,3 +11,10 @@
 
  * Move copy_branch to bzrlib.clone.copy_branch.  The destination
    directory is created if it doesn't exist.
+
+ * Inventories now identify the files which were present by 
+   giving the revision *of that file*.
+
+ * Inventory and Revision XML contains a version identifier.  
+   This must be consistent with the overall branch version
+   but allows for more flexibility in future upgrades.

=== modified file 'bzrlib/xml5.py'
--- bzrlib/xml5.py	2005-10-03 15:19:25 +0000
+++ bzrlib/xml5.py	2005-10-06 06:31:16 +0000
@@ -35,7 +35,8 @@
     
     def _pack_inventory(self, inv):
         """Convert to XML Element"""
-        e = Element('inventory')
+        e = Element('inventory',
+                    format='5')
         e.text = '\n'
         if inv.root.file_id not in (None, ROOT_ID):
             e.set('file_id', inv.root.file_id)
@@ -82,15 +83,14 @@
                        timestamp = '%.9f' % rev.timestamp,
                        revision_id = rev.revision_id,
                        inventory_sha1 = rev.inventory_sha1,
+                       format='5',
                        )
         if rev.timezone:
             root.set('timezone', str(rev.timezone))
         root.text = '\n'
-
         msg = SubElement(root, 'message')
         msg.text = rev.message
         msg.tail = '\n'
-
         if rev.parent_ids:
             pelts = SubElement(root, 'parents')
             pelts.tail = pelts.text = '\n'
@@ -100,7 +100,6 @@
                 p.tail = '\n'
                 p.set('revision_id', parent_id)
         return root
-
     
 
     def _unpack_inventory(self, elt):
@@ -108,6 +107,11 @@
         """
         assert elt.tag == 'inventory'
         root_id = elt.get('file_id') or ROOT_ID
+        format = elt.get('format')
+        if format is not None:
+            if format != '5':
+                raise BzrError("invalid format version %r on inventory"
+                                % format)
         inv = Inventory(root_id)
         for e in elt:
             ie = self._unpack_entry(e)
@@ -154,13 +158,16 @@
     def _unpack_revision(self, elt):
         """XML Element -> Revision object"""
         assert elt.tag == 'revision'
-        
+        format = elt.get('format')
+        if format is not None:
+            if format != '5':
+                raise BzrError("invalid format version %r on inventory"
+                                % format)
         rev = Revision(committer = elt.get('committer'),
                        timestamp = float(elt.get('timestamp')),
                        revision_id = elt.get('revision_id'),
                        inventory_sha1 = elt.get('inventory_sha1')
                        )
-
         parents = elt.find('parents') or []
         for p in parents:
             assert p.tag == 'revision_ref', \
@@ -174,5 +181,4 @@
         return rev
 
 
-
 serializer_v5 = Serializer_v5()

